# Aries Cloudagent Python (Patched) <!-- omit in toc -->

This is a patched fork of Aries Cloudagent Python [v0.5.6](https://github.com/hyperledger/aries-cloudagent-python/tree/0.5.6)

## License

[Apache License Version 2.0](https://github.com/hyperledger/aries-cloudagent-python/blob/master/LICENSE)